tests.factories package
=======================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   tests.factories.input
   tests.factories.pipeline

Submodules
----------

tests.factories.analysis module
-------------------------------

.. automodule:: tests.factories.analysis
   :members:
   :undoc-members:
   :show-inheritance:

tests.factories.analysis\_version module
----------------------------------------

.. automodule:: tests.factories.analysis_version
   :members:
   :undoc-members:
   :show-inheritance:

tests.factories.category module
-------------------------------

.. automodule:: tests.factories.category
   :members:
   :undoc-members:
   :show-inheritance:

tests.factories.run module
--------------------------

.. automodule:: tests.factories.run
   :members:
   :undoc-members:
   :show-inheritance:

tests.factories.user module
---------------------------

.. automodule:: tests.factories.user
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: tests.factories
   :members:
   :undoc-members:
   :show-inheritance:
